.. _install:

Installation
=============

For most *users*, the latest official package can be obtained from the `PyPi <pypi.org/project/clouddrift/>`_ repository: 

.. code-block:: text

  pip install clouddrift

or (soon!) from the conda-forge repository:

.. code-block:: text

  conda install -c conda-forge clouddrift

For *developpers* who want to install the latest development version, you can install directly from the clouddrift's GitHub repository:

.. code-block:: text

  pip install git+https://github.com/Cloud-Drift/clouddrift.git

A quick how-to guide is provided on the `Usage <https://cloud-drift.github.io/clouddrift/usage.html>`_ page.